@@ -15,7 +15,7 @@ pub struct FrameView {
 
 impl Default for FrameView {
     fn default() -> Self {
-        let max_recent = 60 * 60 * 15;
+        let max_recent = 60 * 60 * 5;
         let max_slow = 256;
 
         Self {
@@ -94,7 +94,7 @@ impl FrameView {
     }
 
     /// How many frames of recent history to store.
-    pub fn set_max_history(&mut self, max_recent: usize) {
+    pub fn set_max_recent(&mut self, max_recent: usize) {
         self.max_recent = max_recent;
     }
 
